var namespaces_dup =
[
    [ "blas", "namespaceblas.html", "namespaceblas" ],
    [ "linalg", "namespacelinalg.html", "namespacelinalg" ],
    [ "qrupdate", "namespaceqrupdate.html", "namespaceqrupdate" ],
    [ "sparskit", "namespacesparskit.html", "namespacesparskit" ]
];